@@ -3,7 +3,9 @@
 
 from core_main_app.commons import exceptions as exceptions
 from core_main_app.components.template import api as template_api
-from core_main_app.components.version_manager import api as version_manager_api
+from core_main_app.components.template_version_manager import (
+    api as template_version_manager_api,
+)
 from core_main_registry_app.settings import REGISTRY_XSD_FILENAME
 
 
@@ -19,10 +21,10 @@ def get_current_registry_template(request):
     """
     try:
         template_version = (
-            version_manager_api.get_active_global_version_manager_by_title(
+            template_version_manager_api.get_active_global_version_manager_by_title(
                 REGISTRY_XSD_FILENAME, request=request
             )
         )
-        return template_api.get(template_version.current, request=request)
-    except Exception as e:
-        raise exceptions.ModelError(str(e))
+        return template_api.get_by_id(template_version.current, request=request)
+    except Exception as exception:
+        raise exceptions.ModelError(str(exception))
